@@ -50,28 +50,6 @@ project_parameters = {
     # Data Constants
     "data_n_output": "",
     # Model training constants
-    "model_params_nn": {
-        "batch_size": 4096,
-        "patience": 20,
-        "kernel_init": "uniform",
-        "loss": "mse",
-        "no_layers": 3,
-        "basic_neurons": 512,
-        "activation": "tanh",
-        "dropout": 0.2,
-        "last_activation": "",
-        "learning_rate": 1e-5,
-        "metrics": [
-            "mse",
-            "categorical_accuracy",
-        ],
-        "metric_monitor": "val_loss",
-        "metric_mode": "auto",
-        "early_stopping_min_delta": 1e-5,
-        "max_epochs": 500,
-        "verbose": 1,
-        "model_file": "nn.pkl.gz",
-    },
     "model_params_hgb": {
         "max_iter": 500,
         "max_leaf_nodes": 31,
