@@ -11,10 +11,6 @@ from catboost import CatBoostClassifier, CatBoostRegressor
 from sklearn.ensemble import HistGradientBoostingRegressor
 from sklearn.multioutput import MultiOutputRegressor
 from src.logic import export_predictions
-from tensorflow.keras.callbacks import EarlyStopping, ModelCheckpoint
-from tensorflow.keras.layers import Dense, Dropout, Input, Normalization
-from tensorflow.keras.models import Sequential
-from tensorflow.keras.optimizers import Adamax
 
 from .custom_hgb import CustomHistGradientBoostingClassifier
 from .custom_multi import CustomMultiOutputClassifier
@@ -37,72 +33,11 @@ from .plot import plot_model_results
 from .query import q_delete_run
 
 
-def nn_model_setup(params, num_input, num_output, df_norm) -> Sequential:
-    """Design the nn model architecture.
-
-    Args:
-        params (dict)       : NN parameters
-        num_input (int)     : no. of input variables
-        num_output (int)    : no. of output variables
-        df_norm (dataframe) : chunk of data for normalization
-    Returns:
-        model (keras.models.Sequential): untrained NN model
-    """
-    # Model design
-    model = Sequential()
-    l_in = Input(num_input)
-    model.add(l_in)
-    l_n = Normalization(axis=1)
-    l_n.adapt(df_norm)
-    model.add(l_n)
-
-    nn_params = params["model_params_nn"]
-
-    # Stack Dense layers
-    for idx_layer in range(nn_params["no_layers"]):
-        # Set number of neurons for the current layer
-        no_neurons = int(nn_params["basic_neurons"] / (2**idx_layer))
-
-        # Add Dense layer and dropout
-        model.add(
-            Dense(
-                no_neurons,
-                activation=nn_params["activation"],
-                kernel_initializer=nn_params["kernel_init"],
-            )
-        )
-        model.add(Dropout(nn_params["dropout"]))
-
-    # Last predictive layer
-    if nn_params["last_activation"] != "":
-        model.add(Dense(num_output, activation=nn_params["last_activation"]))
-    else:
-        model.add(Dense(num_output))
-
-    # Compile model
-    model.compile(
-        loss=nn_params["loss"],
-        optimizer=Adamax(learning_rate=nn_params["learning_rate"]),
-        metrics=nn_params["metrics"],
-    )
-
-    print(model.summary())
-
-    return model
-
-
-def ml_setup(params, num_input, num_output, df):
+def ml_setup(params):
     """Model-agnostic setup, initialize the model object."""
     model_type = params["model_type"]
-    if model_type == "nn":
-        model = nn_model_setup(
-            params,
-            num_input,
-            num_output,
-            df,
-        )
     # Allocate here with wanted scikit-learn classifiers
-    elif model_type == "hgb":
+    if model_type == "hgb":
         model_params = params["model_params_hgb"].copy()
         model_params.pop("model_file")
 
@@ -126,27 +61,20 @@ def ml_setup(params, num_input, num_output, df):
     return model
 
 
-def ml_load(params, data):
+def ml_load(params):
     """Model-agnostic loading."""
     msg = "Download model file"
     logger.info(msg)
     insert_logs(params, msg)
 
-    model_type = params["model_type"]
-    if model_type == "nn":
-        model_path = fetch_from_bucket(params, "model")["model"]
-        model = ml_setup(
-            params, data["data_num_input"], data["data_num_output"], data["df_test"]
-        )
-        model.load_weights(model_path)
-    else:
-        model = fetch_from_bucket(params, "model")["model"]
+    model = fetch_from_bucket(params, "model")["model"]
 
     return model
 
 
 def sk_train(params, model, data):
     """Fit multi-output scikit-learn classifier and store the model file."""
+    multi_model = None
     if params["prediction_type"] == "classification":
         params["smote_params"]["categorical_features"] = [0]
         params["smote_params"]["random_state"] = params["random_state"]
@@ -174,65 +102,15 @@ def sk_train(params, model, data):
     return multi_model
 
 
-def nn_train(params, model, data) -> Sequential:
-    """Train of the neural network model.
-
-    Returns:
-        model (keras.models.Sequential): trained NN model object
-    """
-    # # Generators
-    # training_generator = DataGenerator(params, data, mode="train")
-    # validation_generator = DataGenerator(params, data, mode="val")
-
-    nn_params = params["model_params_nn"]
-
-    # Setup callbacks
-    es = EarlyStopping(
-        monitor=nn_params["metric_monitor"],
-        mode=nn_params["metric_mode"],
-        min_delta=nn_params["early_stopping_min_delta"],
-        verbose=nn_params["verbose"],
-        patience=nn_params["patience"],
-    )
-    mc = ModelCheckpoint(
-        filepath=nn_params["path_model_file"],
-        monitor=nn_params["metric_monitor"],
-        mode=nn_params["metric_mode"],
-        verbose=nn_params["verbose"],
-        save_best_only=True,
-    )
-
-    # Model training
-    model.fit(
-        x=data["df_train"],
-        y=data["label_train"],
-        validation_data=(data["df_val"], data["label_val"]),
-        epochs=nn_params["max_epochs"],
-        batch_size=nn_params["batch_size"],
-        callbacks=[es, mc],
-        workers=8,
-        use_multiprocessing=True,
-        max_queue_size=10,
-        verbose=nn_params["verbose"],
-    )
-
-    return model
-
-
 def ml_train(params, model, data):
     """Model-agnostic training."""
-    model_type = params["model_type"]
-    if model_type == "nn":
-        model = nn_train(params, model, data)
-    else:
-        model = sk_train(params, model, data)
+    model = sk_train(params, model, data)
     return model
 
 
 def ml_predict(params, model, df):
     """Model-agnostic predict function."""
-    model_type = params["model_type"]
-    if model_type == "nn" or params["prediction_type"] == "regression":
+    if params["prediction_type"] == "regression":
         # Compute prediction on validation data
         df_pred = model.predict(df)
     else:
@@ -267,7 +145,6 @@ def model_evaluation(params, data):
     Args:
     data (dict): data dictionary in order to evaluate the model.
     """
-    results = {}
     if params["prediction_type"] == "classification":
         results = calculate_mean_average_precision(params, data)
         results.update(kappa_analysis(params, data))
@@ -406,20 +283,16 @@ def cat_regressor_model_setup(params):
 
 def ml_model(params, data):
     """Model-agnostic main function."""
-    if params["model_type"] not in ["nn", "hgb", "cat"]:
-        logger.log("Invalid model type, options: `nn`, `hgb`, and `cat`")
+    if params["model_type"] not in ["hgb", "cat"]:
+        model = None
+        logger.log("Invalid model type, options: `hgb`, and `cat`")
 
     else:
         if params["train_mode"]:
-            model = ml_setup(
-                params,
-                data["data_num_input"],
-                data["data_num_output"],
-                data["df_train"][::10],
-            )
+            model = ml_setup(params)
             model = ml_train(params, model, data)
         else:
-            model = ml_load(params, data)
+            model = ml_load(params)
 
         model = ml_performance(params, model, data)
     return model
@@ -517,7 +390,7 @@ def compute_performance_table(params, data_segment, mode):
 
 def performance_lift(params, data, model):
     """Compute lift."""
-    # Compute scores and actuals for trainval data
+    # Compute scores and actual values for train+val data
     for segment in ["train", "val", "test"]:
         # Compute prediction on data segment
         data[f"pred_{segment}"] = pd.DataFrame(
@@ -581,7 +454,7 @@ def calculate_single_lift_curve(y, y_pred, step=0.01):
     x_val = np.arange(step, 1 + step, step)
     # Calculate the ratio of ones in our data
     ratio_ones = aux_lift["real"].sum() / len(aux_lift)
-    # Create an empty vector with the values that will go on the Y axis our our plot
+    # Create an empty vector with the values that will go on the Y axis of our plot
     y_v = []
 
     # Calculate for each x value its correspondent y value
