@@ -28,7 +28,7 @@ def parse_input(parent_parser=None):
         type=str,
         dest="model_type",
         required=False,
-        help="Type of the model (either 'hgb', 'nn', 'cat', 'lsq' or 'opt')",
+        help="Type of the model (either 'hgb', 'cat', 'lsq' or 'opt')",
     )
     parser.add_argument(
         "--model_id",
@@ -115,7 +115,6 @@ def setup_params(args=None):
         # Force stop run if model_type is not specified
         if "model_type" not in params or params["model_type"] not in [
             "hgb",
-            "nn",
             "cat",
             "lsq",
             "opt",
@@ -181,7 +180,7 @@ def setup_params(args=None):
     ] = f"{params['path_base_gcs_train_data']}-{params['train_data_file']}"
 
     # Create local and bucket path for model based on the model_type
-    if "model_type" in params and params["model_type"] in ["hgb", "nn", "cat", "lsq"]:
+    if "model_type" in params and params["model_type"] in ["hgb", "cat", "lsq"]:
         m_t = params["model_type"]
         params[f"model_params_{m_t}"][
             "path_model_file"
